@@ -1,13 +1,19 @@
 JOB_TYPE_FORECAST_SERIES = "job_forecast"
 JOB_TYPE_DETECT_ANOMALIES_FOR_SERIES = "job_anomaly_detect"
-JOB_TYPE_BASE_SERIES_ANALYSIS = "job_base_analysis"
-JOB_TYPE_STATIC_RULES = "job_static_rules"
+
+JOB_TYPE_IDS = {
+    JOB_TYPE_FORECAST_SERIES: 1,
+    JOB_TYPE_DETECT_ANOMALIES_FOR_SERIES: 2
+}
+
+JOB_TYPE_NAMES = {
+    1: JOB_TYPE_FORECAST_SERIES,
+    2: JOB_TYPE_DETECT_ANOMALIES_FOR_SERIES
+}
 
 JOB_TYPES = [
-    JOB_TYPE_BASE_SERIES_ANALYSIS,
     JOB_TYPE_FORECAST_SERIES,
-    JOB_TYPE_DETECT_ANOMALIES_FOR_SERIES,
-    JOB_TYPE_STATIC_RULES
+    JOB_TYPE_DETECT_ANOMALIES_FOR_SERIES
 ]
 
 JOB_STATUS_NONE = None
