@@ -11,6 +11,7 @@ PROTO_REQ_UPDATE_SERIES = 0x07
 PROTO_REQ_WORKER_REQUEST = 0x08
 PROTO_REQ_WORKER_REQUEST_REDIRECT = 0x09
 PROTO_REQ_EVENT = 0x0a
+PROTO_REQ_WORKER_QUERY = 0x0b
 
 
 PROTO_RES_HANDSHAKE_OK = 0x40
@@ -18,4 +19,5 @@ PROTO_RES_HANDSHAKE_FAIL = 0x41
 PROTO_RES_UNKNOWN_CLIENT = 0x42
 PROTO_RES_HEARTBEAT = 0x43
 PROTO_RES_WORKER_REQUEST = 0x44
-PROTO_RES_WORKER_REQUEST_REDIRECT = 0x45
\ No newline at end of file
+PROTO_RES_WORKER_REQUEST_REDIRECT = 0x45
+PROTO_RES_WORKER_QUERY = 0x46
\ No newline at end of file
