@@ -1,30 +1,5 @@
 import asyncio
 
-HANDSHAKE = 1
-HANDSHAKE_OK = 2
-HANDSHAKE_FAIL = 3
-UNKNOWN_CLIENT = 4
-HEARTBEAT = 5
-SHUTDOWN = 6
-CLIENT_SHUTDOWN = 7
-
-# ADD_SERIES = 8
-# REMOVE_SERIES = 9
-LISTENER_ADD_SERIES = 10
-LISTENER_REMOVE_SERIES = 11
-LISTENER_NEW_SERIES_POINTS = 12
-UPDATE_SERIES = 13
-
-RESPONSE_OK = 14
-
-WORKER_REQUEST = 15
-WORKER_REQUEST_RESULT = 16
-WORKER_REQUEST_RESULT_REDIRECT = 17
-
-EVENT = 18
-WORKER_QUERY = 19
-WORKER_QUERY_RESULT = 20
-
 
 '''
 Header:
@@ -44,9 +19,6 @@ async def read_packet(sock, header_data=None):
     if header_data is False:
         return None, None, None, False
     body_size, packet_type = read_header(header_data)
-    if packet_type == WORKER_REQUEST_RESULT_REDIRECT:
-        header_data = await read_full_data(sock, 16)
-        pool_id, worker_id = read_extended_header(header_data)
     return packet_type, pool_id, worker_id, await read_full_data(sock, body_size)
 
 
