@@ -7,7 +7,7 @@ from random import randrange
 import signal
 from time import time
 from enodo.model.enodoevent import ENODO_EVENT_WORKER_ERROR, EnodoEvent
-from enodo.net import PROTO_REQ_WORKER_REQUEST, PROTO_RES_WORKER_REQUEST
+from enodo.net import (PROTO_REQ_WORKER_REQUEST, PROTO_RES_WORKER_REQUEST, PROTO_REQ_EVENT)
 from enodo.worker.analyser.analyser import start_analysing
 from enodo.version import __version__
 from enodo.worker.con import WorkerProtocol
@@ -19,9 +19,8 @@ from enodo.jobs import JOB_TYPE_IDS
 from .hub import ClientManager
 
 import qpack
-from enodo.protocol.package import (
-    EVENT, create_header)
-from enodo.protocol.packagedata import EnodoRequestResponse
+from enodo.protocol.package import create_header
+from enodo.protocol.packagedata import QUERY_SUBJECT_STATE, QUERY_SUBJECT_STATS, EnodoQuery, EnodoRequestResponse
 
 from .modules import module_load
 
@@ -112,16 +111,11 @@ class WorkerServer:
 
     async def create(self, loop: asyncio.AbstractEventLoop):
         self._server_running = True
-        # self._server = await asyncio.start_server(
-        #     self._handle_client_connection, self._hostname, self._port,
-        #     loop=loop)
-
         await loop.create_server(
             lambda: WorkerProtocol(worker=self), host=None, port=self._port)
 
     async def stop(self):
         self._server_running = False
-        # await self._server.close()
 
     async def _cleanup(self):
         while self._server_running:
@@ -187,7 +181,7 @@ class WorkerServer:
                 "Error occured in worker", response.error,
                 ENODO_EVENT_WORKER_ERROR, response.series_name)
             event = qpack.packb(event)
-            header = create_header(len(event), EVENT)
+            header = create_header(len(event), PROTO_REQ_EVENT)
             hub_id = response.request.get('hub_id')
             if hub_id in self._clients:
                 self._clients[hub_id].writer.write(header + event)
@@ -196,6 +190,23 @@ class WorkerServer:
             await self._upsert_state(response.series_name, response.result)
         await self.send_response_to_hub(response, response.request)
 
+    def get_query_result(self, query: EnodoQuery) -> EnodoQuery:
+        if query.subject == QUERY_SUBJECT_STATE:
+            query['result'] = self._states.get(query.series_name)
+        elif query.subject == QUERY_SUBJECT_STATS:
+            query['result'] = self._get_stats()
+        return query
+
+
+    def _get_stats(self):
+        return {
+            "hostname": self._config.get('WORKER_HOSTNAME'),
+            "port": int(self._config.get('WORKER_PORT')),
+            "jobs_in_queue": self._open_jobs.qsize(),
+            "busy": isinstance(self._worker_process, Process) and \
+                        self._worker_process.is_alive()
+        }
+
     async def send_response_to_hub(self, response, request):
         pool_id = request['pool_id']
         worker_id = request['worker_id']
